<!DOCTYPE html>
<html>
<head lang="en">
    <meta charset="UTF-8">
    <title>Login</title>
    {% load oneall %}
    {% oneall_header %}
    {# Bootstrap is not required. This is just to give us some non-hideous default look. #}
    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.5/css/bootstrap.min.css">
</head>
<body>
<div class="container">
    <div class="row">
        <h1>Login</h1>

        {% if login_failed %}
            <div id="login_failed">Login failed!</div>
        {% endif %}

        {% if logged_out %}
            <div id="logged_out">Logged out!</div>
        {% endif %}

        <div class="col-sm-6">
            <h2>Social Login</h2>

            {% oneall_social_login %}
        </div>
        <form method="post" class="col-sm-6">
            {% csrf_token %}
            <h2>Email Login</h2>
            {% if check_your_mail %}
                Check your e-mail for the login link.
            {% else %}
                {{ email_form.as_p }} <input type="submit" value=" Login "/>
            {% endif %}
        </form>
    </div>
</div>
</body>
</html>